Default SQLite implementation for wasi-sql
This is a lightweight implementation for development use only.
Structs
- Connect
Options - Options used to connect to the SQL database.
- SqlDefault
- Default implementation for
wasi:sql.
Default SQLite implementation for wasi-sql
This is a lightweight implementation for development use only.
wasi:sql.