pub struct ConnectionProxy(pub Arc<dyn Connection>);Expand description
ConnectionProxy provides a concrete wrapper around a dyn Connection object.
It is used to store connection resources in the resource table.
Tuple Fields
0: Arc<dyn Connection>Trait Implementations
Sourceimpl Clone for ConnectionProxy
impl Clone for ConnectionProxy
Sourcefn clone(&self) -> ConnectionProxy
fn clone(&self) -> ConnectionProxy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionProxy
impl Debug for ConnectionProxy