Connection

Trait Connection 

pub trait Connection:
    Debug
    + Send
    + Sync
    + 'static {
    // Required methods
    fn query(
        &self,
        query: String,
        params: Vec<DataType>,
    ) -> FutureResult<Vec<Row>>;
    fn exec(&self, query: String, params: Vec<DataType>) -> FutureResult<u32>;
}
SQL providers implement the Connection trait to allow the host to connect to a backend (Azure Table Storage, Postgres, etc) and execute SQL statements.

Required Methods

fn query(&self, query: String, params: Vec<DataType>) -> FutureResult<Vec<Row>>

Execute a query and return the resulting rows.

fn exec(&self, query: String, params: Vec<DataType>) -> FutureResult<u32>

Execute a query that does not return rows (e.g., an INSERT, UPDATE, or DELETE).

Implementors